@@ -11,7 +11,7 @@ class meets_tanf_non_cash_gross_income_test(Variable):
     def formula(spm_unit, period, parameters):
         state = spm_unit.household("state_code_str", period)
         # All limits and incomes here expressed as % of FPG.
-        limits = parameters(period).hhs.tanf.non_cash.income_limit
+        limits = parameters(period).gov.hhs.tanf.non_cash.income_limit
         gross_limit = limits.gross[state]
         gross_income = spm_unit("snap_gross_income_fpg_ratio", period)
         return gross_income <= gross_limit
