@@ -14,7 +14,7 @@ class eitc_reduction(Variable):
         highest_income_variable = max_(
             earnings, tax_unit("adjusted_gross_income", period)
         )
-        phaseout_start = tax_unit("eitc_phaseout_start", period)
-        phaseout_rate = tax_unit("eitc_phaseout_rate", period)
-        phaseout_region = max_(0, highest_income_variable - phaseout_start)
-        return phaseout_rate * phaseout_region
+        phase_out_start = tax_unit("eitc_phase_out_start", period)
+        phase_out_rate = tax_unit("eitc_phase_out_rate", period)
+        phase_out_region = max_(0, highest_income_variable - phase_out_start)
+        return phase_out_rate * phase_out_region
