@@ -13,7 +13,7 @@ class ma_income_tax_exemption_threshold(Variable):
     def formula(tax_unit, period, parameters):
         filing_status = tax_unit("filing_status", period)
         dependents = tax_unit("tax_unit_dependents", period)
-        tax = parameters(period).states.ma.tax.income
+        tax = parameters(period).gov.states.ma.tax.income
         exempt_status = tax.exempt_status.limit
         personal_exemptions_added = (
             exempt_status.personal_exemption_added[filing_status]
